@@ -15,7 +15,15 @@ from simple_term_menu import TerminalMenu
 from pbsrollout.check_cluster_ready import check_cluster_ready
 from pbsrollout.k8s_utils import import_kube_config
 from pbsrollout.process_cluster import cutover_service, launch_pods, remove_old_pods, Status
-from pbsrollout.utils import notify
+from pbsrollout.utils import notify, get_latest_version
+
+VERSION = ""
+try:
+    import importlib.metadata
+
+    VERSION = importlib.metadata.version("pbsrollout")
+except:
+    pass
 
 CLUSTERS = [
     "aws.us-east-1-eks-23-v3",
@@ -46,10 +54,28 @@ def print_help(console):
     console.print(md)
 
 
+def check_latest_version(console: Console):
+    latest_version = get_latest_version()
+    if latest_version != "":
+        if latest_version != VERSION:
+            terminal_menu = TerminalMenu(["[y] yes", "[n] It's okay I want to keep an outdated version"],
+                                         title=f"You pbsrollout version is outdated!\n- Current version: {VERSION}\n- Latest version: {latest_version}\nDo you want to update?",
+                                         raise_error_on_interrupt=True)
+            menu_entry_index = terminal_menu.show()
+            if menu_entry_index == 0:
+                console.print(f"Please run: [grey66]python3 -m pip install --upgrade pbsrollout\n")
+                exit(0)
+
+
 def print_welcome(console):
-    console.print(
-        "[blink underline italic dark_orange3]Better[/blink underline italic dark_orange3] [bold medium_purple3]Rollout[/bold medium_purple3]\n\n",
-        justify="center")
+    if VERSION != "":
+        console.print(
+            f"[blink underline italic dark_orange3]Better[/blink underline italic dark_orange3] [bold medium_purple3]Rollout[/bold medium_purple3] (v{VERSION})\n\n",
+            justify="center")
+    else:
+        console.print(
+            "[blink underline italic dark_orange3]Better[/blink underline italic dark_orange3] [bold medium_purple3]Rollout[/bold medium_purple3]\n\n",
+            justify="center")
     regions = {
         'US': [],
         'EU': [],
@@ -77,7 +103,8 @@ def get_cluster_name(c):
 def update_prebid_tag(path: str, tag: str):
     console = Console()
     path += "/namespace/api/pbs.prod.tag"
-    console.print(f"Updating prebid tag to [bold blue_violet]{tag}[/bold blue_violet] in file: [bold light_steel_blue1]{path}[/bold light_steel_blue1]")
+    console.print(
+        f"Updating prebid tag to [bold blue_violet]{tag}[/bold blue_violet] in file: [bold light_steel_blue1]{path}[/bold light_steel_blue1]")
     with open(path, "w") as f:
         f.write(tag)
 
@@ -93,15 +120,35 @@ def ask_for_tag() -> str:
 
 
 def ask_to_open_datadog():
-    terminal_menu = TerminalMenu(["[y] yes", "[n] I will open it myself!"], title=f"Please check datadog! Do you want me to open it for you?\n{DD_BOARD_URL}",
+    terminal_menu = TerminalMenu(["[y] yes", "[n] I will open it myself!"],
+                                 title=f"Please check datadog! Do you want me to open it for you?\n{DD_BOARD_URL}",
                                  raise_error_on_interrupt=True)
     menu_entry_index = terminal_menu.show()
     if menu_entry_index == 0:
         os.system(f"open '{DD_BOARD_URL}'")
 
 
+def ask_if_git_pull():
+    terminal_menu = TerminalMenu(["[y] yes", "[n] no, I want to live a dangerous life! (and maybe break the prebid)"],
+                                 title=f"Please check that you ran git pull and are on the master branch!\nis your repository clean?",
+                                 raise_error_on_interrupt=True)
+    menu_entry_index = terminal_menu.show()
+    if menu_entry_index != 0:
+        raise RuntimeError("Fix your git and restart this script (git checkout master and git pull)")
+
+
+def ask_if_want_git_push(tag):
+    terminal_menu = TerminalMenu(["[y] yes", "[n] no"],
+                                 title=f"Do you want me to run this command for you?",
+                                 raise_error_on_interrupt=True)
+    menu_entry_index = terminal_menu.show()
+    if menu_entry_index == 0:
+        os.system(f"git add namespace/api/pbs.prod.tag; git commit -m 'updating pbs to tag: {tag} with better_rollout'; git push")
+
+
 def ask_if_everything_look_fine_after_all_cutover() -> bool:
-    terminal_menu = TerminalMenu(["[y] yes", "[n] no"], title=f"Is everything fine? (check datadog)\n{DD_BOARD_URL}",
+    terminal_menu = TerminalMenu(["[y] yes, let's remove the old pods right now!", "[n] no, we need to rollback"],
+                                 title=f"Is everything fine? (check datadog)\n{DD_BOARD_URL}",
                                  raise_error_on_interrupt=True)
     menu_entry_index = terminal_menu.show()
     return menu_entry_index == 0
@@ -134,7 +181,10 @@ def _main():
         return 1
     gopath = os.environ['GOPATH']
 
-    console.print("[bold red]Please run[/bold red] [italic misty_rose1]git pull --rebase[italic misty_rose1] [bold red]before running this script![/bold red]")
+    console.print(
+        "[bold red]Please run[/bold red] [italic misty_rose1]git pull --rebase[italic misty_rose1] [bold red]before running this script![/bold red]")
+
+    ask_if_git_pull()
 
     # 1. CD Inside the prebid kube manifest directory
     prebid_k8s_path = gopath + '/src/github.com/publica-project/prebid-kube-manifests'
@@ -197,6 +247,7 @@ def _main():
         console.print("\n[bold green]Done! Don't forget to add the file to git and commit it!")
         console.print(
             f"[grey66]git add namespace/api/pbs.prod.tag; git commit -m 'updating pbs to tag: {tag} with better_rollout'; git push")
+        ask_if_want_git_push(tag)
         return 0
 
 
@@ -207,6 +258,7 @@ def main():
         print_help(console)
     print("\n\n")
     try:
+        check_latest_version(console)
         _main()
     except Exception as e:
         notify("Error during Rollout prebid!", "PBS Rollout", sound=True)
